@@ -12,15 +12,13 @@
 
 import json
 import re
+from unittest import mock
 
-import django
 from django.conf import settings
 from django.core import exceptions
 from django.test.utils import override_settings
 from django.urls import reverse
 from django.utils import html
-import mock
-import six
 
 from heatclient.common import template_format as hc_format
 from openstack_dashboard import api as dashboard_api
@@ -93,11 +91,7 @@ class MappingsTests(test.TestCase):
         self.assertEqual(u'', mappings.stack_output(None))
 
         outputs = ['one', 'two', 'three']
-        # On Python 3, the pretty JSON output doesn't add space before newline
-        if six.PY3:
-            expected_text = """[\n  "one",\n  "two",\n  "three"\n]"""
-        else:
-            expected_text = """[\n  "one", \n  "two", \n  "three"\n]"""
+        expected_text = """[\n  "one",\n  "two",\n  "three"\n]"""
 
         self.assertEqual(u'<pre>%s</pre>' % html.escape(expected_text),
                          mappings.stack_output(outputs))
@@ -353,23 +347,13 @@ class StackTests(test.TestCase):
         self.assertTemplateUsed(res, 'project/stacks/create.html')
 
         # ensure the fields were rendered correctly
-        if (1, 10) <= django.VERSION < (2, 1):
-            pattern = ('<input class="form-control" '
-                       'id="id___param_public_string" '
-                       'name="__param_public_string" type="text" required/>')
-            secret = ('<input class="form-control" '
-                      'id="id___param_secret_string" '
-                      'name="__param_secret_string" '
-                      'type="password" required>')
-        else:
-            pattern = ('<input class="form-control" '
-                       'id="id___param_public_string" '
-                       'name="__param_public_string" type="text" />')
-            secret = ('<input class="form-control" '
-                      'id="id___param_secret_string" '
-                      'name="__param_secret_string" '
-                      'type="password" />')
-
+        pattern = ('<input class="form-control" '
+                   'id="id___param_public_string" '
+                   'name="__param_public_string" type="text" required/>')
+        secret = ('<input class="form-control" '
+                  'id="id___param_secret_string" '
+                  'name="__param_secret_string" '
+                  'type="password" required>')
         self.assertContains(res, pattern, html=True)
         self.assertContains(res, secret, html=True)
         self.mock_template_validate.assert_called_once_with(
@@ -511,32 +495,16 @@ class StackTests(test.TestCase):
         self.assertTemplateUsed(res, 'project/stacks/create.html')
 
         # ensure the fields were rendered correctly
-        if (1, 10) <= django.VERSION < (2, 1):
-            input_str = ('<input class="form-control" '
-                         'id="id___param_param{0}" '
-                         'name="__param_param{0}" type="{1}" required/>')
-        else:
-            input_str = ('<input class="form-control" '
-                         'id="id___param_param{0}" '
-                         'name="__param_param{0}" type="{1}"/>')
+        input_str = ('<input class="form-control" '
+                     'id="id___param_param{0}" '
+                     'name="__param_param{0}" type="{1}" required/>')
         self.assertContains(res, input_str.format(3, 'text'), html=True)
         self.assertContains(res, input_str.format(4, 'text'), html=True)
 
-        if (1, 11) <= django.VERSION < (2, 1):
-            input_str_param2 = ('<input type="number" name="__param_param2" '
-                                'autocomplete="off" '
-                                'required class="form-control" '
-                                'id="id___param_param2" />')
-        elif (1, 10) <= django.VERSION < (1, 11):
-            input_str_param2 = ('<input autocomplete="off" '
-                                'class="form-control" id="id___param_param2" '
-                                'name="__param_param2" type="number" '
-                                'required />')
-        else:
-            input_str_param2 = ('<input autocomplete="off" '
-                                'class ="form-control" '
-                                'id="id___param_param2" '
-                                'name="__param_param2" type="number" />')
+        input_str_param2 = ('<input type="number" name="__param_param2" '
+                            'autocomplete="off" '
+                            'required class="form-control" '
+                            'id="id___param_param2" />')
         self.assertContains(res, input_str_param2, html=True)
 
         # post some sample data and make sure it validates
